@@ -13,6 +13,14 @@ class VersionError(ValueError):
     def __init__(self, msg='Invalid MAPDL version'):
         ValueError.__init__(self, msg)
 
+
+class NoDistributedFiles(FileNotFoundError):
+    """Unable to find any distributed result files """
+
+    def __init__(self, msg='Unable to find any distributed result files'):
+        FileNotFoundError.__init__(self, msg)
+
+
 class MapdlRuntimeError(RuntimeError):
     """Raised when MAPDL passes an error"""
     pass
